@@ -19,6 +19,15 @@ get_release() {
 	8*)
 	    release="jessie"
 	;;
+	9*)
+	    release="stretch"
+	;;
+	10*)
+	    release="buster"
+	;;
+	11*)
+	    release="bullseye"
+	;;
 	*)
 	    echo "ERROR: unable to identify release for version $version" >&2
 	    exit 1
@@ -27,15 +36,23 @@ get_release() {
     echo "$release"
 }
 
+get_publish_directory() {
+    local lang="${1:-en-US}"
+    local format="${2:-html}"
+    local version=$(get_product_version)
+    echo "publish/$lang/Debian/$version/$format"
+}
+
 parse_options() {
     local temp
-    temp=$(getopt -o l:so: -l lang:,skip,opts: -- "$@")
+    temp=$(getopt -o l:so:p -l lang:,skip,opts:,paperback -- "$@")
     eval set -- "$temp"
     while true; do
 	case "$1" in
 	    -l|--lang) OPT_lang="$2"; shift 2; ;;
 	    -o|--opts) OPT_opts="$2"; shift 2; ;;
 	    -s|--skip) OPT_skip="1"; shift 1; ;;
+	    -p|--paperback) OPT_paperback="1"; shift 1; ;;
 	    --) shift; break; ;;
 	    *) echo "ERROR: Invalid command-line option: $1" >&2; exit 1; ;;
 	esac
